==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/admin/inc/syntax/clssipgatewaysgrid.php <==
<?
require_once "inc/syntax/clswebservicegrid.php";

/*************** FTP GRID *********************/
class cSIPGatewaysGrid extends cWebserviceGrid
{
	function cSIPGatewaysGrid($option)
	{
		$this->Name = "sip_gateways";
		$this->Filename = $_SESSION["INSTALLPATH"].$option["SOURCE"][0]["FILE"][0]["ATTRIBUTES"]["NAME"];
	}
	function LoadFromXML()
	{
	  //Save load XML
	  if (file_exists($this->Filename))
	  {
      $parser = new ParseXML();
      $xml = $parser->GetXMLTree($this->Filename);
      $items = $xml["GATEWAYS"][0]["GATEWAY"];
      unset($parser);
    }
    if($items) foreach ($items as $index => $host)
      if ($host) foreach ($host as $var => $value)
          $return[$index][strtolower($var)] = $this->xml2arr($value,$var);
    $this->Data = $return;
	}
	function saveToXML()
  {
    foreach ($this->Data as $index => $host)
      foreach ($host as $var=>$value){
        if (!($var=='value' && !isset($value[0]["VALUE"]))) $return[$index][strtoupper($var)] = $this->arr2xml($value,strtolower($var)); 
        }
      return $return;
  }
	function Save()
  {
    $arr = $this->SaveToXML();
    $xml["GATEWAYS"][0]["GATEWAY"] = $arr;
    $parser = new ParseXML();
    $xmlstr = $parser->Array2XML($xml,true);
    if ($xmlstr!="") {
      $fp = @fopen($this->Filename,'w');
  		fwrite($fp,trim($xmlstr));
  		@fclose($fp);
    }else @unlink($this->Filename);
  }
	function xml2arr($item,$key)
	{
	  $m = 0;
	  switch (strtolower($key)){
	    case 'targetusers':
	    case 'restrictedusers':
	       if (is_array($item) && trim($item[0]["VALUE"])!="" ){
              $members = explode(";",$item[0]["VALUE"]);
              foreach ($members as $member)
                if ($member) $return[$m++]["member"] = $member;
         }
      break;
	    case 'value':
      default:
          if (is_array($item) && trim($item[0]["VALUE"])!="" ) $return =  $item[0]["VALUE"];
      break;
    }
    return $return;
  }
  function arr2xml($value,$key)
  {
      switch(strtolower($key)){
      case "restrictedusers":
      case "targetusers":
          if ($value) foreach ($value as $k=>$v)
            $return[0]["VALUE"].=$v["member"].";";
       break;
      default:
        $return[0]['VALUE'] = $value;
      break;
    }
    return $return;
  }
  function getObjectJS($selector,$vindex,$aFunction = false,$option)
	{
		global $skin_dir,$sGridItem;
		/*selector name */
		$arr["dname"] = $this->Name;
		
    @$files = $option["SOURCE"][0]["FILE"][0]["ATTRIBUTES"];
		@$dialog = $files["DIALOG"];
		@$file = $files["NAME"];
		@$comment = $files["COMMENT"];
		@$width = $option["ATTRIBUTES"]["WIDTH"];
		if (@!$width) $width=640;
		@$height = $option["ATTRIBUTES"]["HEIGHT"];
		if (@!$height) $height=480;
		
		if ($this->Data)
		foreach($this->Data as $key2 => $val2){
			foreach ($vindex as $key3 => $val3){
			  $val = strtolower($val3);
        $item = eregi_replace("([\\\'\"])","\\\\1",$val2[$val3]);
				$arr["items"]["num"][$key2]["num"][$key3] = str_replace(CRLF,";",$item);
        $arr["items"]["num"][$key2]["num"][$key3] = '<a href="javascript:processdatagrid(\\\'edit\\\',\\\''.$dialog.'\\\',\\\''.$this->Name.'\\\',\\\'\\\','.$width.','.$height.',\\\'\\\',\\\''.$this->count.'\\\',0,\\\''.$key2.'\\\');">'.$arr["items"]["num"][$key2]["num"][$key3].'</a>';
			}
			$arr["items"]["num"][$key2]["cislo"]= $key2;
			if ($this->Name.$key2==$sGridItem) $arr["items"]["num"][$key2]["selected"]=1;
		}
		$arr["selector"]=$selector;
		return template($skin_dir."dgridjs2.tpl",$arr);
	}
}

?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/admin/inc/syntax/clssipgatewaysgrid.php <==
<?
require_once "inc/syntax/clswebservicegrid.php";

/*************** FTP GRID *********************/
class cSIPGatewaysGrid extends cWebserviceGrid
{
	function cSIPGatewaysGrid($option)
	{
		$this->Name = "sip_gateways";
		$this->Filename = $_SESSION["CONFIGPATH"].$option["SOURCE"][0]["FILE"][0]["ATTRIBUTES"]["NAME"];
	}
	function LoadFromXML()
	{
	  //Save load XML
	  if (file_exists($this->Filename))
	  {
      $parser = new ParseXML();
      $xml = $parser->GetXMLTree($this->Filename);
      $items = $xml["GATEWAYS"][0]["GATEWAY"];
      unset($parser);
    }
    if($items) foreach ($items as $index => $host)
      if ($host) foreach ($host as $var => $value)
          $return[$index][strtolower($var)] = $this->xml2arr($value,$var);
    $this->Data = $return;
	}
	function saveToXML()
  {
    if($this->Data) foreach ($this->Data as $index => $host)
      if($host) foreach ($host as $var=>$value){
        if (!($var=='value' && !isset($value[0]["VALUE"]))) $return[$index][strtoupper($var)] = $this->arr2xml($value,strtolower($var)); 
        }
      return $return;
  }
	function Save()
  {
    $arr = $this->SaveToXML();
    $xml["GATEWAYS"][0]["GATEWAY"] = $arr;
    $parser = new ParseXML();
    $xmlstr = $parser->Array2XML($xml,true);
    if ($xmlstr!="") {
      $fp = @fopen($this->Filename,'w');
  		fwrite($fp,trim($xmlstr));
  		@fclose($fp);
    }else @unlink($this->Filename);
  }
	function xml2arr($item,$key)
	{
	  $m = 0;
	  switch (strtolower($key)){
	    case 'targetusers':
	    case 'restrictedusers':
	       if (is_array($item) && trim($item[0]["VALUE"])!="" ){
              $members = explode(";",$item[0]["VALUE"]);
              if($members) foreach ($members as $member)
                if ($member) $return[$m++]["member"] = $member;
         }
      break;
	    case 'value':
      default:
          if (is_array($item) && trim($item[0]["VALUE"])!="" ) $return =  $item[0]["VALUE"];
      break;
    }
    return $return;
  }
  function arr2xml($value,$key)
  {
      switch(strtolower($key)){
      case "restrictedusers":
      case "targetusers":
          if ($value) foreach ($value as $k=>$v)
            $return[0]["VALUE"].=$v["member"].";";
       break;
      default:
        $return[0]['VALUE'] = $value;
      break;
    }
    return $return;
  }
  function getObjectJS($selector,$vindex,$aFunction = false,$option)
	{
		global $skin_dir,$sGridItem;
		/*selector name */
		$arr["dname"] = $this->Name;
		
    @$files = $option["SOURCE"][0]["FILE"][0]["ATTRIBUTES"];
		@$dialog = $files["DIALOG"];
		@$file = $files["NAME"];
		@$comment = $files["COMMENT"];
		@$width = $option["ATTRIBUTES"]["WIDTH"];
		if (@!$width) $width=640;
		@$height = $option["ATTRIBUTES"]["HEIGHT"];
		if (@!$height) $height=480;
		
		if ($this->Data)
		foreach($this->Data as $key2 => $val2){
			if($vindex) foreach ($vindex as $key3 => $val3){
			  $val = strtolower($val3);
        $item = eregi_replace("([\\\'\"])","\\\\1",$val2[$val3]);
				$arr["items"]["num"][$key2]['item']["num"][$key3]['value'] = str_replace(CRLF,";",$item);
        $arr["items"]["num"][$key2]['item']["num"][$key3]['label'] = '<a href="javascript:processdatagrid(\\\'edit\\\',\\\''.$dialog.'\\\',\\\''.$this->Name.'\\\',\\\'\\\','.$width.','.$height.',\\\'\\\',\\\''.$this->count.'\\\',0,\\\''.$key2.'\\\',\\\''.$this->uid.'\\\');">'.$arr["items"]["num"][$key2]['item']["num"][$key3]['value'].'</a>';
        $arr["items"]["num"][$key2]['item']["num"][$key3]['sort'] = '<a href="javascript:processdatagrid(\\\'edit\\\',\\\''.$dialog.'\\\',\\\''.$this->Name.'\\\',\\\'\\\','.$width.','.$height.',\\\'\\\',\\\''.$this->count.'\\\',0,\\\''.$key2.'\\\',\\\''.$this->uid.'\\\');">'.$arr["items"]["num"][$key2]['item']["num"][$key3]['value'].'</a>';
			}
			$arr["items"]["num"][$key2]["cislo"]= $key2;
			if ($this->Name.$key2==$sGridItem) $arr["items"]["num"][$key2]["selected"]=1;
		}
		$arr["selector"]=$selector;
		return template($skin_dir."dgridjs2.tpl",$arr);
	}
}

?>
